WhatsappZeroTapPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • WhatsappZeroTapPlatform
Implementers

Constructors

WhatsappZeroTapPlatform()
Constructs a WhatsappZeroTapPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isWhatsAppInstalled() Future<bool>
isWhatsAppOtpHandshakeSupported() Future<bool>
listenForOTP({required Duration timeout}) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WhatsappZeroTapPlatform
The default instance of WhatsappZeroTapPlatform to use.
getter/setter pair